@@ -10,7 +10,8 @@
 # Version: 0.082 (04 Sep 2001)
 # Version: 0.083 (15 Apr 2008)
 # Version: 0.084 (13 Jun 2008)
-# Version: 0.085 (28 Nob 2013)
+# Version: 0.085 (28 Nov 2013)
+# Version: 0.086 (11 Dec 2013)
 #
 #######################################################################
 
@@ -154,7 +155,7 @@ sub AUTOLOAD {
 #######################################################################
 # STATIC OBJECT PROPERTIES
 #
-$VERSION = "0.085";
+$VERSION = "0.086";
 
 %callback_code = ();
 %callback_info = ();
@@ -2800,6 +2801,10 @@ use, refer to the Microsoft Win32 Internet Functions document.
 
 =over
 
+=item * 0.086 (11 Dec 2013)
+
+Really fix required perl version 5.6 -> 5.006 in META.yml.
+
 =item * 0.085 (28 Nov 2013)
 
 HttpSendRequest() now works for binary data too.
@@ -3050,6 +3055,4 @@ This program is FREE; you can redistribute, modify, disassemble, or
 even reverse engineer this software at your will. Keep in mind,
 however, that NOTHING IS GUARANTEED to work and everything you do is
 AT YOUR OWN RISK - I will not take responsibility for any damage, loss
-of money and/or health that may arise from the use of this program!
-
-This is distributed under the terms of Larry Wall's Artistic License.
+of money and/or hea                                                                                                                        
\ No newline at end of file
